@@ -44,8 +44,10 @@ def parse_playlist_header(response: Dict) -> Dict[str, Any]:
         playlist["duration"] = (
             None if not has_duration else second_subtitle_runs[has_views + has_duration]["text"]
         )
-        song_count = second_subtitle_runs[has_views + 0]["text"].split(" ")
-        song_count = to_int(song_count[0]) if len(song_count) > 1 else 0
+        song_count_text = second_subtitle_runs[has_views + 0]["text"]
+        song_count_search = re.search(r"\d+", song_count_text)
+        # extract the digits from the text, return 0 if no match
+        song_count = to_int(song_count_search.group()) if song_count_search is not None else 0
         playlist["trackCount"] = song_count
 
     return playlist
@@ -112,8 +114,7 @@ def parse_playlist_item(
         navigation_endpoint = nav(flex_column_item, [*TEXT_RUN, "navigationEndpoint"], True)
 
         if not navigation_endpoint:
-            if nav(flex_column_item, TEXT_RUN_TEXT, True) is not None:
-                unrecognized_index = index if unrecognized_index is None else unrecognized_index
+            unrecognized_index = index if unrecognized_index is None else unrecognized_index
             continue
 
         if "watchEndpoint" in navigation_endpoint:
